@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Robert Ransom
 
 ; Interpreting commands.
 
@@ -99,7 +101,8 @@
 
 (define (display-command-level-condition condition)
   (if condition
-      (display-condition condition (command-output))))
+      (display-condition condition (command-output)
+			 (condition-writing-depth) (condition-writing-length))))
 
 ; If #T anything that doesn't start with the command prefix (a comma) is
 ; treated as an argument to RUN.  If #F no commas are needed and RUN
@@ -141,29 +144,30 @@
 ; warnings on the command level thread to avoid circularity problems.
 
 (define (command-loop-condition-handler c next-handler)
-  (let ((c (coerce-to-condition c)))
-    (cond ((or (warning? c)
-	       (note? c))
-	   (if (break-on-warnings?)
-	       (deal-with-condition c)
-	       (begin (force-output (current-output-port)) ; keep synchronous
-		      (display-condition c (current-error-port))
-		      (unspecific))))	;proceed
-	  ((or (error? c) (bug? c) (interrupt? c))
-	   (if (batch-mode?)
-	       (begin (force-output (current-output-port)) ; keep synchronous
-		      (display-condition c (current-error-port))
-		      (let ((status
-			     (cond
-			      ((error? c) 1)
-			      ((bug? c) 3) ; historical, probably nonsense
-			      (else 2))))
-			(scheme-exit-now status)))
-	       (deal-with-condition c)))
-	  ((reset-command-input? c)
-	   (unspecific))		;proceed
-	  (else                           
-	   (next-handler)))))
+  (cond ((or (warning? c)
+	     (note? c))
+	 (if (break-on-warnings?)
+	     (deal-with-condition c)
+	     (begin (force-output (current-output-port)) ; keep synchronous
+		    (display-condition c (current-error-port)
+				       (condition-writing-depth) (condition-writing-length))
+		    (unspecific))))	;proceed
+	((or (serious-condition? c) (interrupt-condition? c))
+	 (if (batch-mode?)
+	     (begin (force-output (current-output-port)) ; keep synchronous
+		    (display-condition c (current-error-port)
+				       (condition-writing-depth) (condition-writing-length))
+		    (let ((status
+			   (cond
+			    ((error? c) 1)
+			    ((violation? c) 3) ; historical, probably nonsense
+			    (else 2))))
+		      (scheme-exit-now status)))
+	     (deal-with-condition c)))
+	((reset-command-input-condition? c)
+	 (unspecific))			;proceed
+	(else                           
+	 (next-handler))))
 
 ; Stop the current level either by pushing a new one or restarting it.
 ; If we restart the current level we save it as the focus object to give
@@ -174,7 +178,8 @@
       (command-loop c)
       (let ((level (car (command-levels))))
 	(set-focus-object! level)
-	(display-condition c (command-output))
+	(display-condition c (command-output)
+			   (condition-writing-depth) (condition-writing-length))
 	(restart-command-level level))))
 
 (define (abort-to-command-level level)
@@ -247,12 +252,12 @@
    (lambda (k)
      (with-handler
       (lambda (c punt)
-	(let ((c (coerce-to-condition c)))
-	  (if (or (error? c) (bug? c))
-	      (begin
-		(display-condition c (current-error-port))
-		(k (EX_SOFTWARE)))
-	      (punt))))
+	(if (serious-condition? c)
+	    (begin
+	      (display-condition c (current-error-port)
+				 (condition-writing-depth) (condition-writing-length))
+	      (k (EX_SOFTWARE)))
+	    (punt)))
       (lambda ()
 	(thunk)
 	0)))))
@@ -319,8 +324,7 @@
 	 with-limited-output
 	 (lambda (p) (p)))
      (lambda ()
-       (write-carefully (value->expression result)
-			out)
+       (write-carefully result out)
        (newline out)))))
 
 ;----------------
@@ -453,7 +457,8 @@
 	  (and (not (eqv? value #t))
 	       (not (eqv? value #f)))
 	  (not ((setting-type setting) value)))
-      (error "invalid value for setting" (setting-name setting) value))
+      (error 'setting-set!
+	     "invalid value for setting" (setting-name setting) value))
   ((setting-set setting) value))
 
 (define (setting-doc setting)
@@ -572,22 +577,6 @@
              (newline o-port)
              (loop (cdr s1) (if (null? s2) s2 (cdr s2))))))))
                    
-;----------------
-; Utilities
-
-(define (error-form proc args)
-  (cons proc (map value->expression args)))
-
-; Print non-self-evaluating value X as 'X.
-
-(define (value->expression obj)         ;mumble
-  (if (or (symbol? obj)
-	  (pair? obj)
-	  (null? obj)
-	  (vector? obj))
-      `',obj
-      obj))
-
 (define (write-spaces count o-port)
   (do ((count count (- count 1)))
       ((<= count 0))
@@ -622,13 +611,14 @@
 (define *y-or-n-eof-count* 100)
 
 (define (read-line port)
-  (let loop ((l '()))
+  (let loop ((l '())
+             (llen 0))
     (let ((c (read-char port)))
       (if (eof-object? c)
           c
           (if (char=? c #\newline)
-              (list->string (reverse l))
-              (loop (cons c l)))))))
+              (reverse-list->string l llen)
+              (loop (cons c l) (+ 1 llen)))))))
 
 (define (greet-user info)
   (let ((port (command-output)))
@@ -638,7 +628,7 @@
         (begin (write-char #\space port)
                (display info port)))
     (newline port)
-    (write-line "Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees."
+    (write-line "See http://s48.org/ for more information."
 		port)
     (write-line "Please report bugs to scheme-48-bugs@s48.org."
                 port)
