@@ -1,6 +1,15 @@
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Mike Sperber, Robert Ransom
+
 (define-structure posix-core-test (export posix-core-tests)
-  (open scheme test-suites sort threads
+  (open scheme test-suites matchers sort threads
 	util		; every
+        (with-prefix srfi-1 srfi-1:)
+        threads
+        (subset threads-internal (terminate-thread!))
+        placeholders
+        queues
 	posix-files
 	posix-time
 	posix-users
@@ -11,7 +20,7 @@
   (files check))
 
 (define-structure regexp-test (export regexp-tests)
-  (open scheme test-suites
+  (open scheme test-suites matchers
 	regexps)
   (files regexp-check))
 
