@@ -1,3 +1,8 @@
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Mike Sperber, David van Horn,
+; Martin Gasbichler, Michael Zabka, Emilio Lopes
+
 ;----------------
 ; SRFI packages
 
@@ -43,14 +48,14 @@
 (define-structure srfi-1 srfi-1-interface
   (open (modify scheme-level-2 (hide map for-each member assoc)) ; redefined
 	receiving
-	(subset signals (error)))
+	(subset exceptions (assertion-violation)))
   (files srfi-1))
 
 ; AND-LET*: an AND with local bindings, a guarded LET* special form
 
 (define-structure srfi-2 (export (and-let* :syntax))
   (open scheme-level-2
-	signals)		; error
+	exceptions)		; error
   (files srfi-2))
 
 ; SRFI-3 - withdrawn
@@ -111,34 +116,39 @@
 
 ; Configuration language
 
-(define-structure srfi-7 (export)      ; defines a command
+(define-structure srfi-7 (export program)	; also defines a command
   (open scheme
 
-        ; for parsing programs
+	; for parsing programs
 	receiving
 	nondeterminism
-	(subset signals (error))
-	
+	(subset exceptions (assertion-violation))
+
 	(subset evaluation			(eval-from-file))
-	
+
 	(subset package-commands-internal	(config-package))
 	ensures-loaded
 	(subset packages			(note-structure-name!))
-	
-        ; for defining the command
-	(subset command-processor               (define-user-command-syntax
+
+	; for defining the command
+	(subset command-processor		(define-user-command-syntax
 						 user-command-environment))
-	(subset environments                    (environment-define!)))
+	(subset environments			(environment-define! environment-ref))
+        
+        ; for opening needed packages during evaluation
+        (subset package-mutation                (package-open!))
+        (subset packages                        (make-modified-structure)))
 
   (begin
     (define available-srfis
       '(srfi-1 srfi-2 srfi-4 srfi-5 srfi-6 srfi-7 srfi-8 srfi-9
 	srfi-11 srfi-13 srfi-14 srfi-16 srfi-17 srfi-19
 	srfi-23 srfi-25 srfi-26 srfi-27 srfi-28
-	srfi-31 srfi-34 srfi-35 srfi-36 srfi-37
+	srfi-31 srfi-34 srfi-37
 	srfi-39 srfi-40 srfi-42 srfi-43 srfi-45
-        srfi-60 srfi-61 srfi-63 sfi-66 srfi-67
-	srfi-71 srfi-74 srfi-78))
+        srfi-60 srfi-61 srfi-62 srfi-63 srfi-66 srfi-67
+	srfi-71 srfi-74 srfi-78
+	srfi-95))
 
     ; Some SRFI's redefine Scheme variables.
     (define shadowed
@@ -156,16 +166,11 @@
   (files srfi-7))
 
 ; receive: Binding to multiple values
-; Taken directly from the SRFI document (or from `receiving', take your pick).
+; Identical to the version in UTIL
 
 (define-structure srfi-8 (export (receive :syntax))
-  (open scheme-level-2)
-  (begin
-    (define-syntax receive
-      (syntax-rules ()
-	((receive formals expression body ...)
-	 (call-with-values (lambda () expression)
-			   (lambda formals body ...)))))))
+  (open scheme-level-2
+	util))
 
 ; Defining Record Types
 ; SRFI-9 is a slight modification of DEFINE-RECORD-TYPE.
@@ -237,11 +242,13 @@
 	  string string-append list->string))
 
 (define-structure srfi-13 srfi-13-interface
-  (open scheme-level-2
+  (open (modify scheme-level-2
+		(hide string-copy string-upcase string-downcase string-titlecase string-fill! string->list))
 	bitwise
 	srfi-8 srfi-14
-	unicode-char-maps
-	(subset signals		(error)))
+	(modify unicode-char-maps
+		(hide string-upcase string-downcase string-titlecase))
+	(subset exceptions (assertion-violation)))
   (files srfi-13))
 
 ; Character-Set Library
@@ -295,10 +302,11 @@
 	(subset primitives (copy-bytes! unspecific))
 	inversion-lists
 	srfi-9
+	(subset define-record-types (define-record-discloser))
 	variable-argument-lists
 	(subset big-util (partition-list))
 	(subset features (make-immutable!))
-	(subset signals (call-error)))
+	(subset exceptions (assertion-violation)))
   (optimize auto-integrate)
   (files srfi-14
 	 srfi-14-base-char-sets ; auto-generated
@@ -310,14 +318,14 @@
 
 (define-structure srfi-16 (export (case-lambda :syntax))
   (open scheme-level-2
-	(subset signals (error)))
+	(subset exceptions (assertion-violation)))
   (files srfi-16))
 
 ; Generalized set!
 
 (define-structure srfi-17 (export (set! :syntax) setter)
   (open (modify scheme-level-2 (rename (set! scheme-set!)))
-	(subset signals (error))
+	(subset exceptions (assertion-violation))
 	(subset util (unspecific)))
   (files srfi-17))
 
@@ -418,7 +426,7 @@
         srfi-23 ; ERROR
         ascii
         receiving
-        (modify posix-time (prefix posix:))
+        (modify os-time (prefix os-time:))
         (modify extended-ports
                 (rename (make-string-output-port open-output-string)
                         (string-output-port-output get-output-string)
@@ -432,7 +440,12 @@
 ; Error reporting mechanism
 
 (define-structure srfi-23 (export error)
-  (open (subset signals (error))))
+  (open scheme
+	(modify exceptions
+		(rename (error exceptions:error))))
+  (begin
+    (define (error message . irritants)
+      (apply exceptions:error #f message irritants))))
 
 ; Multi-dimensional Array Primitives 
 
@@ -443,7 +456,7 @@
 (define-structure srfi-25 srfi-25-interface
   (open scheme
 	define-record-types
-	(subset signals (error)))
+	(subset exceptions (assertion-violation)))
   (files srfi-25))
 
 ; Notation for Specializing Parameters without Currying
@@ -486,7 +499,7 @@
 
 (define-structure srfi-28 srfi-28-interface
   (open scheme
-	(subset signals (error))
+	(subset exceptions (assertion-violation))
 	srfi-6				; string ports
 	)
   (files srfi-28))
@@ -519,53 +532,6 @@
   (open scheme
 	exceptions))
 
-; Conditions
-
-(define-interface srfi-35-interface
-  (export make-condition-type
-	  condition-type?
-	  make-condition
-	  condition?
-	  condition-has-type?
-	  condition-ref
-	  make-compound-condition
-	  extract-condition
-
-	  (define-condition-type :syntax)
-	  (condition :syntax)
-
-	  &condition
-	  &message message-condition? condition-message
-	  &serious serious-condition?
-	  &error error?))
-
-(define-structure srfi-35 srfi-35-interface
-  (open scheme
-	conditions))
-
-; I/O Conditions
-
-(define-interface srfi-36-interface
-  (export &i/o-error i/o-error?
-	  &i/o-port-error i/o-port-error?
-	  i/o-error-port
-	  &i/o-read-error i/o-read-error?
-	  &i/o-write-error i/o-write-error?
-	  &i/o-closed-error i/o-closed-error?
-	  &i/o-filename-error i/o-filename-error?
-	  i/o-error-filename
-	  &i/o-malformed-filename-error i/o-malformed-filename-error?
-	  &i/o-file-protection-error i/o-file-protection-error?
-	  &i/o-file-is-read-only-error i/o-file-is-read-only-error?
-	  &i/o-file-already-exists-error i/o-file-already-exists-error?
-	  &i/o-no-such-file-error i/o-no-such-file-error?
-	  &read-error read-error?
-	  read-error-line read-error-column read-error-position read-error-span))
-
-(define-structure srfi-36 srfi-36-interface
-  (open scheme
-	i/o-conditions))
-
 ; SRFI 37: args-fold: a program argument processor
 
 (define-interface srfi-37-interface
@@ -587,7 +553,7 @@
 
 (define-structure srfi-39 srfi-39-interface
   (open scheme
-	signals
+	exceptions
         fluids
         cells)
   (files srfi-39))
@@ -656,7 +622,7 @@
                 (rename (list->vector %list->vector)))
         (modify util (rename (unspecific unspecified-value)))
         (subset srfi-8 (receive))
-        (subset signals (error)))
+        (subset exceptions (assertion-violation)))
   (files srfi-43))
 
 ; SRFI 45: Primitives for Expressing Iterative Lazy Algorithms
@@ -665,7 +631,7 @@
   (export (lazy :syntax) force (delay :syntax)))
 
 (define-structure srfi-45 srfi-45-interface
-  (open scheme
+  (open (modify scheme (hide delay force))
 	define-record-types)
   (files srfi-45))
 
@@ -693,6 +659,21 @@
   (open (modify scheme (hide cond)))
   (files srfi-61))
 
+; SRFI 62: S-expression comments
+
+; note this modifies the reader
+(define-structure srfi-62 (export)
+  (open scheme
+	reading)
+  (begin
+    (define-sharp-macro #\;
+      (lambda (char port)
+	;; The octothorpe reader leaves the semicolon
+	;; in the input stream, so we consume it.
+	(read-char port)
+	(sub-read-carefully port)
+	(sub-read port)))))
+
 ; SRFI 63: Homogeneous and Heterogeneous Arrays
 
 (define-interface srfi-63-interface
@@ -710,7 +691,7 @@
   (open (modify scheme-level-2 (hide equal?)) ; redefined
         define-record-types
         srfi-4 srfi-16
-        (subset signals (error)))  
+        (subset exceptions (assertion-violation)))
   (files srfi-63))
 
 ; SRFI 66: Octet Vectors
@@ -857,5 +838,17 @@
 
 (define-structure srfi-78 srfi-78-interface
   (open scheme srfi-42
-        (subset signals (error)))
+        (subset exceptions (assertion-violation)))
   (files srfi-78))
+
+; SRFI 95: Sorting and Merging
+
+(define-interface srfi-95-interface
+  (export sorted? merge merge! sort sort!))
+
+(define-structure srfi-95 srfi-95-interface
+  (open (modify scheme (hide equal?)) srfi-63
+	(modify sorting (prefix olin:))
+	(modify list-merge-sort (prefix olin:))
+	(modify vector-merge-sort (prefix olin:)))
+  (files srfi-95))
