@@ -1,5 +1,8 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
-; Copyright (c) 2005-2006 by Basis Technology Corporation.  See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Mike Sperber, Robert Tansom
+
+; Copyright (c) 2005-2006 by Basis Technology Corporation. 
 
 ; This is basically a complete re-implementation, suitable for Unicode.
 
@@ -43,6 +46,11 @@
   (i-list char-set-i-list
 	  set-char-set-i-list!))
 
+(define-record-discloser :char-set
+  (lambda (cs)
+    (list 'char-set
+	  (char-set-size cs))))
+
 (define (make-char-set-immutable! char-set)
   (make-immutable! char-set)
   (make-immutable! (char-set-simple char-set)))
@@ -367,7 +375,7 @@
     (if (not (and (integer? bound)
 		  (exact? bound)
 		  (<= 0 bound)))
-	(call-error "invalid bound" char-set-hash bound))
+	(assertion-violation 'char-set-hash "invalid bound" bound))
     (let ((bound (if (zero? bound) 4194304 bound)))
       (modulo (+ (simple-cset-hash (char-set-simple cs) bound)
 		 (* 37 (inversion-list-hash (char-set-i-list cs) bound)))
@@ -583,15 +591,15 @@
 
 (define (ucs-range->char-set! lower upper error? base-cs)
   (if (negative? lower)
-      (call-error "negative lower bound" ucs-range->char-set! lower))
+      (assertion-violation 'ucs-range->char-set! "negative lower bound" lower))
   (if (> lower #x10ffff)
-      (call-error "invalid lower bound" ucs-range->char-set! lower))
+      (assertion-violation 'ucs-range->char-set! "invalid lower bound" lower))
   (if (negative? upper)
-      (call-error "negative upper bound" ucs-range->char-set! upper))
+      (assertion-violation 'ucs-range->char-set! "negative upper bound" upper))
   (if (> upper #x110000)
-      (call-error "invalid lower bound" ucs-range->char-set! upper))
+      (assertion-violation 'ucs-range->char-set! "invalid lower bound" upper))
   (if (not (<= lower upper))
-      (call-error "decreasing bounds" ucs-range->char-set! lower upper))
+      (assertion-violation 'ucs-range->char-set! "decreasing bounds" lower upper))
 
   (let ((create-inversion-list
 	 (lambda (lower upper)
@@ -646,7 +654,7 @@
   (cond ((char-set? x) x)
 	((string? x) (string->char-set x))
 	((char? x) (char-set x))
-	(else (call-error "->char-set: Not a charset, string or char." x->char-set))))
+	(else (assertion-violation 'x->char-set "Not a charset, string or char."))))
 
 
 ; Set algebra
@@ -743,17 +751,20 @@
     (lambda (simple-diff simple-intersection)
       (set-char-set-simple! cs1 simple-diff)
       (set-char-set-simple! cs2 simple-intersection)
-      (set-char-set-i-list! cs1
-			    (apply inversion-list-difference
-				   (char-set-i-list cs1)
-				   (char-set-i-list cs2)
-				   (map char-set-i-list csets)))
-      (set-char-set-i-list! cs2 (inversion-list-intersection
-				 (char-set-i-list cs1)
-				 (apply inversion-list-union
-					(char-set-i-list cs2)
-					(map char-set-i-list csets))))
-      (values cs1 cs2))))
+      (let ((i-list-1 (char-set-i-list cs1))
+	    (i-list-2 (char-set-i-list cs2))
+	    (i-list-rest (map char-set-i-list csets)))
+	(set-char-set-i-list! cs1
+			      (apply inversion-list-difference
+				     i-list-1 i-list-2
+				     i-list-rest))
+	(set-char-set-i-list! cs2
+			      (inversion-list-intersection
+			       i-list-1
+			       (apply inversion-list-union
+				      i-list-2
+				      i-list-rest)))
+	(values cs1 cs2)))))
 
 (define (char-set-diff+intersection cs1 . csets)
   (apply char-set-diff+intersection!
@@ -779,18 +790,6 @@
 	  (p i (byte-vector-ref s i))
 	  (loop (- i 1))))))
 
-(define (byte-vector=? b1 b2)
-  (let ((size-1 (byte-vector-length b1))
-	(size-2 (byte-vector-length b2)))
-    (and (= size-1 size-2)
-	 (let loop ((i 0))
-	   (cond
-	    ((>= i size-1) #t)
-	    ((= (byte-vector-ref b1 i) (byte-vector-ref b2 i))
-	     (loop (+ 1 i)))
-	    (else
-	      #f))))))
-
 ;; Utility for srfi-14-base-char-sets.scm, which follows
 
 ; The range vector is an even-sized vector with [lower, upper)
